@@ -13,6 +13,10 @@ def getmac():
     mac_formated = ':'.join(("%012x" % mac)[i:i+2] for i in range(0, 12, 2))
     return mac_formated
 
+def name():
+    f = footprint.footprint()
+    return getname(f)
+
 def id():
     f = footprint.footprint()
     name = getname(f)
